Examples
############


Physiological
=============

.. toctree::
   :maxdepth: 1

   bio_eventrelated/bio_eventrelated
   bio_intervalrelated/bio_intervalrelated
   bio_custom/bio_custom
   ecg_hrv/ecg_hrv
   ecg_heartbeats/ecg_heartbeats
   ecg_delineate/ecg_delineate
   ecg_edr/ecg_edr
   ecg_generate_12leads/ecg_generate_12leads
   eda_peaks/eda_peaks
   rsp_rrv/rsp_rrv
   eog_analyze/eog_analyze
   signal_simulation/signal_simulation
   ppg_report/ppg_report

EEG
=============

.. toctree::
   :maxdepth: 1

   eeg_power/eeg_power
   eeg_complexity/eeg_complexity
   eeg_microstates/eeg_microstates

Misc
=============

.. toctree::
   :maxdepth: 1

   misc_fit_function/misc_fit_function
   misc_epochs_create/misc_epochs_create